==> amazon_cognito_identity_dart-0.0.15%2B1.tar.gz: test/cognito_user_exceptions_test.dart <==
import 'package:test/test.dart';
import 'package:amazon_cognito_identity_dart/cognito.dart';

void main() {
  test('throw CognitoUserNewPasswordRequiredException generates message', () {
    final t = () => throw new CognitoUserNewPasswordRequiredException();
    try {
      t();
    } on CognitoUserNewPasswordRequiredException catch (e) {
      expect(e.toString(), equals('CognitoUserException: New Password required'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: New Password required'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: New Password required'));
    }
  });
  test('throw CognitoUserMfaRequiredException generates message', () {
    final t = () => throw new CognitoUserMfaRequiredException();
    try {
      t();
    } on CognitoUserMfaRequiredException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SMS_MFA"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SMS_MFA"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SMS_MFA"'));
    }
  });
  test('throw CognitoUserSelectMfaTypeException generates message', () {
    final t = () => throw new CognitoUserSelectMfaTypeException();
    try {
      t();
    } on CognitoUserSelectMfaTypeException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SELECT_MFA_TYPE"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SELECT_MFA_TYPE"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SELECT_MFA_TYPE"'));
    }
  });
  test('throw CognitoUserMfaSetupException generates message', () {
    final t = () => throw new CognitoUserMfaSetupException();
    try {
      t();
    } on CognitoUserMfaSetupException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "MFA_SETUP"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "MFA_SETUP"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "MFA_SETUP"'));
    }
  });
  test('throw CognitoUserTotpRequiredException generates message', () {
    final t = () => throw new CognitoUserTotpRequiredException();
    try {
      t();
    } on CognitoUserTotpRequiredException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SOFTWARE_TOKEN_MFA"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SOFTWARE_TOKEN_MFA"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SOFTWARE_TOKEN_MFA"'));
    }
  });
  test('throw CognitoUserCustomChallengeException generates message', () {
    final t = () => throw new CognitoUserCustomChallengeException();
    try {
      t();
    } on CognitoUserCustomChallengeException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "CUSTOM_CHALLENGE"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "CUSTOM_CHALLENGE"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "CUSTOM_CHALLENGE"'));
    }
  });
  test('throw CognitoUserConfirmationNecessaryException generates message', () {
    final t = () => throw new CognitoUserConfirmationNecessaryException();
    try {
      t();
    } on CognitoUserConfirmationNecessaryException catch (e) {
      expect(e.toString(), equals('CognitoUserException: User Confirmation Necessary'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: User Confirmation Necessary'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: User Confirmation Necessary'));
    }
  });
}

==> amazon_cognito_identity_dart_2-0.1.12%2B1.tar.gz: test/cognito_user_exceptions_test.dart <==
import 'package:amazon_cognito_identity_dart_2/cognito.dart';
import 'package:test/test.dart';

void main() {
  test('throw CognitoUserNewPasswordRequiredException generates message', () {
    final t = () => throw CognitoUserNewPasswordRequiredException();
    try {
      t();
    } on CognitoUserNewPasswordRequiredException catch (e) {
      expect(
          e.toString(), equals('CognitoUserException: New Password required'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(
          e.toString(), equals('CognitoUserException: New Password required'));
    }
    try {
      t();
    } catch (e) {
      expect(
          e.toString(), equals('CognitoUserException: New Password required'));
    }
  });
  test('throw CognitoUserMfaRequiredException generates message', () {
    final t = () => throw CognitoUserMfaRequiredException();
    try {
      t();
    } on CognitoUserMfaRequiredException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SMS_MFA"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SMS_MFA"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SMS_MFA"'));
    }
  });
  test('throw CognitoUserSelectMfaTypeException generates message', () {
    final t = () => throw CognitoUserSelectMfaTypeException();
    try {
      t();
    } on CognitoUserSelectMfaTypeException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SELECT_MFA_TYPE"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SELECT_MFA_TYPE"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "SELECT_MFA_TYPE"'));
    }
  });
  test('throw CognitoUserMfaSetupException generates message', () {
    final t = () => throw CognitoUserMfaSetupException();
    try {
      t();
    } on CognitoUserMfaSetupException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "MFA_SETUP"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "MFA_SETUP"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "MFA_SETUP"'));
    }
  });
  test('throw CognitoUserTotpRequiredException generates message', () {
    final t = () => throw CognitoUserTotpRequiredException();
    try {
      t();
    } on CognitoUserTotpRequiredException catch (e) {
      expect(
          e.toString(), equals('CognitoUserException: "SOFTWARE_TOKEN_MFA"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(
          e.toString(), equals('CognitoUserException: "SOFTWARE_TOKEN_MFA"'));
    }
    try {
      t();
    } catch (e) {
      expect(
          e.toString(), equals('CognitoUserException: "SOFTWARE_TOKEN_MFA"'));
    }
  });
  test('throw CognitoUserCustomChallengeException generates message', () {
    final t = () => throw CognitoUserCustomChallengeException();
    try {
      t();
    } on CognitoUserCustomChallengeException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "CUSTOM_CHALLENGE"'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(), equals('CognitoUserException: "CUSTOM_CHALLENGE"'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(), equals('CognitoUserException: "CUSTOM_CHALLENGE"'));
    }
  });
  test('throw CognitoUserConfirmationNecessaryException generates message', () {
    final t = () => throw CognitoUserConfirmationNecessaryException();
    try {
      t();
    } on CognitoUserConfirmationNecessaryException catch (e) {
      expect(e.toString(),
          equals('CognitoUserException: User Confirmation Necessary'));
    }
    try {
      t();
    } on CognitoUserException catch (e) {
      expect(e.toString(),
          equals('CognitoUserException: User Confirmation Necessary'));
    }
    try {
      t();
    } catch (e) {
      expect(e.toString(),
          equals('CognitoUserException: User Confirmation Necessary'));
    }
  });
}
